@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 __author__ = "JanKinCai"
 __all__ = [
     "rpcap",
@@ -12,6 +12,7 @@ __all__ = [
 
 
 try:
-    from pylibpcap.pcap import rpcap, wpcap, mpcap, mpcaps, sniff, get_first_iface
+    from pylibpcap.pcap import rpcap, wpcap, mpcap, sniff, get_first_iface
+    from pylibpcap.open import OpenPcap
 except ImportError:
     pass
